from distutils.core import setup

setup(
    name = "MyDist",
    version = '1.1.0',
    py_modules = ['nester'],
    author='Ricardo',
    author_email='ricardo@gmail.com',
    url='sorry:(',
    description="A simple test distribution"

)